Image and audio files for pyroids application.

## Licensing

### Artwork

Copyright 2019, Marcus Read

License: [Creative Commons Attribution 4.0 International](https://creativecommons.org/licenses/by/4.0/)

**Except:**

* [explosion.png](explosion.png), [smoke.png](smoke,png)
  * Modified versions of an [animation sequence](https://opengameart.org/content/fire-and-smoke-static-and-trail) kindly made available under [Creative Commons CC0 1.0](https://creativecommons.org/publicdomain/zero/1.0/) by [samoliver](https://opengameart.org/users/samoliver).

### Audio

Copyright 2019, Marcus Read

License: [Creative Commons Attribution 4.0 International](https://creativecommons.org/licenses/by/4.0/)

**Except:**
* [thrusters.wav](thrusters.wav)
  * Minimially modified version of [Rocket Thrusters](http://soundbible.com/1492-Rocket-Thrusters.html) kindly made available under [Creative Commons Sampling Plus 1.0](https://creativecommons.org/licenses/sampling+/1.0/) by dobroride.
* [mr_minelaid.wav](mr_minelaid.wav), [nn_minelaid.wav](nn_minelaid.wav)
  * Incorporate [Metronome](http://soundbible.com/914-Metronome.html) kindly made available under [Creative Commons Attribution 3.0](https://creativecommons.org/licenses/by/3.0/) by Mike Koenig.
* [starburst.wav](starburst.wav)
  * Curtailed version of [Gun Shot](http://soundbible.com/2004-Gun-Shot.html) kindly made available under [Creative Commons Attribution 3.0](https://creativecommons.org/licenses/by/3.0/) by Marvin.